@@ -39,9 +39,9 @@
 
 #include "akonadiagentbase_debug.h"
 
+#include "shared/akranges.h"
 #include <cstdlib>
 #include <iterator>
-#include <shared/akranges.h>
 
 #include <KAboutData>
 #include <KLocalizedString>
@@ -174,7 +174,7 @@ public:
                    "createItemSyncInstance",
                    "Calling items retrieval methods although no item retrieval is in progress");
         if (!mItemSyncer) {
-            mItemSyncer = new ItemSync(q->currentCollection());
+            mItemSyncer = new ItemSync(q->currentCollection(), mCollectionSyncTimestamp);
             mItemSyncer->setTransactionMode(mItemTransactionMode);
             mItemSyncer->setBatchSize(mItemSyncBatchSize);
             mItemSyncer->setMergeMode(mItemMergeMode);
@@ -440,6 +440,7 @@ public:
     QSet<QByteArray> mKeepLocalCollectionChanges;
     KJob *mCurrentCollectionFetchJob = nullptr;
     bool mScheduleAttributeSyncBeforeCollectionSync;
+    QDateTime mCollectionSyncTimestamp;
 };
 
 ResourceBase::ResourceBase(const QString &id)
@@ -845,11 +846,11 @@ namespace
 bool sortCollectionsForSync(const Collection &l, const Collection &r)
 {
     const auto lType = l.hasAttribute<SpecialCollectionAttribute>() ? l.attribute<SpecialCollectionAttribute>()->collectionType() : QByteArray();
-    const bool lInbox = (lType == "inbox") || (QStringView(l.remoteId()).mid(1).compare(QLatin1String("inbox"), Qt::CaseInsensitive) == 0);
+    const bool lInbox = (lType == "inbox") || (QStringView(l.remoteId()).mid(1).compare(QLatin1StringView("inbox"), Qt::CaseInsensitive) == 0);
     const bool lFav = l.hasAttribute<FavoriteCollectionAttribute>();
 
     const auto rType = r.hasAttribute<SpecialCollectionAttribute>() ? r.attribute<SpecialCollectionAttribute>()->collectionType() : QByteArray();
-    const bool rInbox = (rType == "inbox") || (QStringView(r.remoteId()).mid(1).compare(QLatin1String("inbox"), Qt::CaseInsensitive) == 0);
+    const bool rInbox = (rType == "inbox") || (QStringView(r.remoteId()).mid(1).compare(QLatin1StringView("inbox"), Qt::CaseInsensitive) == 0);
     const bool rFav = r.hasAttribute<FavoriteCollectionAttribute>();
 
     // inbox is always first
@@ -937,6 +938,7 @@ void ResourceBasePrivate::slotItemRetrievalCollectionFetchDone(KJob *job)
         q->cancelTask(i18n("Failed to retrieve collection for sync."));
         return;
     }
+    mCollectionSyncTimestamp = QDateTime::currentDateTimeUtc();
     q->retrieveItems(collections.at(0));
 }
 
