@@ -19,12 +19,12 @@
 #include "resource_manager.h"
 #include "serverinterface.h"
 
-#include <private/dbus_p.h>
-#include <private/instance_p.h>
-#include <private/protocol_p.h>
-#include <private/standarddirs_p.h>
+#include "private/dbus_p.h"
+#include "private/instance_p.h"
+#include "private/protocol_p.h"
+#include "private/standarddirs_p.h"
 
-#include <shared/akapplication.h>
+#include "shared/akapplication.h"
 
 #include <QCoreApplication>
 #include <QDBusConnection>
@@ -794,12 +794,12 @@ bool AgentManager::checkResourceInterface(const QString &identifier, const QStri
         return false;
     }
 
-    if (!mAgents[mAgentInstances[identifier]->agentType()].capabilities.contains(QLatin1String("Resource"))) {
+    if (!mAgents[mAgentInstances[identifier]->agentType()].capabilities.contains(QLatin1StringView("Resource"))) {
         return false;
     }
 
     if (!mAgentInstances[identifier]->hasResourceInterface()) {
-        qCWarning(AKONADICONTROL_LOG) << QLatin1String("AgentManager::") + method << " Agent instance " << identifier << " has no resource interface!";
+        qCWarning(AKONADICONTROL_LOG) << QLatin1StringView("AgentManager::") + method << " Agent instance " << identifier << " has no resource interface!";
         return false;
     }
 
